coldp.NameBundle
================

.. currentmodule:: coldp

Class
~~~~~

.. automethod:: coldp.NameBundle.__init__

Methods
~~~~~~~

.. automethod:: coldp.NameBundle.add_synonym
.. automethod:: coldp.NameBundle.normalise_name
.. automethod:: coldp.NameBundle.derive_name

Index and search 
~~~~~~~~~~~~~~~~

* :ref:`genindex`
* :ref:`search`
